@@ -57,7 +57,11 @@ static void cleanup(int sig)
 	signal(SIGFPE, SIG_DFL);
 	signal(SIGSEGV, SIG_DFL);
 
-	sound->deinit();
+	/* Don't deinit from signal handler
+	 * (https://github.com/cmatsuoka/xmp-cli/issues/5)
+	 * sound->deinit();
+	 */
+
 	reset_tty();
 
 	signal(sig, SIG_DFL);
@@ -278,6 +282,8 @@ int main(int argc, char **argv)
 		    opt.interp == XMP_INTERP_SPLINE ? "cubic spline interpolated " : "",
 		    opt.format & XMP_FORMAT_MONO ? "mono" : "stereo",
 		    opt.dsp & XMP_DSP_LOWPASS ? "" : " (no filter)");
+
+		report("Press 'h' for help\n\n");
 	}
 
 	if (opt.probeonly) {
